@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '1.004001'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 use parent 'Exporter';
 use Test::Builder;
@@ -185,7 +185,7 @@ Test::Version - Check to see that version's in modules are sane
 
 =head1 VERSION
 
-version 1.004001
+version 1.05
 
 =head1 SYNOPSIS
 
@@ -306,7 +306,7 @@ The goal is to have the functionality of all of these.
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/xenoterracide/test-version/issues
+https://github.com/plicease/test-version/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -340,13 +340,23 @@ particle <particle@cpan.org>
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Graham Ollis <plicease@cpan.org>
+
+=item *
 
 Caleb Cushing <xenoterracide@gmail.com>
 
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Caleb Cushing.
+This software is Copyright (c) 2015 by Caleb Cushing.
 
 This is free software, licensed under:
 
